// SPDX-License-Identifier: GPL-3.0
//
// Copyright (C) 2019, Donald Dugger
//

import document from "document";
import { logger } from "../common/utils";
import * as utils from "../common/utils";

let V;

var now;
var year;
var month;
var day;

var day_week;
var days_month;

let cal_start;

export function init(_V, _O)
{

  V = _V;

  utils.text_btn("um_btn", "Calendar", "fb-white", "fb-blue", (btn) => {
    utils.bounce("face_%", _V);
  });
  now = new Date();

  utils.text_btn("lm_btn", "", "fb-white", "fb-blue", (btn) => {
    utils.bounce("month", _V, _O);
  });

  let m_btn = document.getElementById("mo");
  m_btn.addEventListener("click", (ev) => {
    new_month(cal_start > 0 ? -1 : 1);
  });

  let btn = document.getElementById("t0");
  btn.addEventListener("click", (ev) => {
    var d;
    let idx = utils.cell_idx(ev, 18, 98, 40, 30);
    let mdays = utils.days_per_mo(year, month);
    let index = idx + cal_start;
    if (index < day_week)
      d = 1;
    else if (index > (day_week + mdays))
      d = mdays;
    else
      d = index - day_week + 1;
    utils.bounce("event", V, {
                            year: year,
                            month: month,
                            day: d
                          });
  });

  new_date(_O.date.getFullYear(), _O.date.getMonth(), _O.date.getDate());

  return false;
}

function reset_date(d)
{

  year = d.getFullYear();
  month = d.getMonth();
  day = d.getDate();
  let dt = new Date(year, month, 1);
  day_week = dt.getDay();
  days_month = utils.days_per_mo(year, month);
}

function new_date(year, month, day)
{

  reset_date(new Date(year, month, day));
  set_days();
}

function set_day(idx, d, today, hi)
{

  let m = document.getElementById("m" + idx);
  let t = m.getElementById("h_text");
  t.text = (d > 0) ? (d + "") : "";
  let b = m.getElementById("h_box");
  b.style.display = (d == today) ? "inline" : "none";
  let b = m.getElementById("h_back");
  b.style.fill = hi ? "slategray" : "black";
}

// Get label for a calendar entry
//
// cd - calendar entry (0 - 36)
//
function cal_day(cd)
{

  if (cd < day_week)
    return 0;
  let l = cd - day_week + 1;
  if (l > days_month)
    return 0;
  return l;
}

function set_days()
{
  let l, today;

  utils.label_btn("um_btn", utils.m_name(month));

  utils.label_btn("lm_btn", year + "");

  if (year == now.getFullYear() && month == now.getMonth())
    today = now.getDate();
  else
    today = -1;

  cal_start = ((day + day_week - 1) >= 21) ? 21 : 0;

  let idx;
  for (let i = 0; i < 21; i++) {
    idx = i + cal_start;
    l = cal_day(idx, day_week, days_month);
    set_day(i, l, today, utils.day_events(year, month, l));
  }
}

function new_year(inc)
{

  year += inc;
  new_date(year, month, day);
}

function new_month(inc)
{

  if (cal_start == 0 && inc > 0)
    day = days_month;
  else if (cal_start != 0 && inc < 0)
    day = 1;
  else {
    month += inc;
    if (month > 11) {
      year += 1;
      month = 0;
    } else if (month < 0) {
      year -= 1;
      month = 11;
    }
    day = (inc > 0) ? 1 : utils.days_per_mo(year, month);
  }

  new_date(year, month, day);
}
