// SPDX-License-Identifier: GPL-3.0
//
// Copyright (C) 2019, Donald Dugger
//

import document from "document";
import { logger } from "../common/utils";
import * as utils from "../common/utils";

let V;

var now;
var year;
var month;
var day_week;

export function init(_V, _O)
{

  V = _V;

  utils.scr_init("Calendar", _V);
  now = new Date();

  utils.text_btn("lm_btn", "", "fb-white", "fb-blue", (btn) => {
    V.G.ev_date = new Date();
    reset_date(V.G.ev_date);
  });

  reset_date(_O.date);
  new_year(0);

  utils.image_btn("ul_btn", "icons/left_btn.png", (btn) => {
    new_month(-1);
  });
  utils.image_btn("ur_btn", "icons/right_btn.png", (btn) => {
    new_month(1);
  });

  utils.image_btn("ll_btn", "icons/left_btn.png", (btn) => {
    new_year(-1);
  });
  utils.image_btn("lr_btn", "icons/right_btn.png", (btn) => {
    new_year(1);
  });

  let ndays = utils.days_per_mo(year, month);
  for (let i = 0; i < 36; i++)
    set_handler(i, ndays);
  set_days();

  return false;
}

function set_handler(idx, days)
{

  let mo_days = days + 1;
  let m = document.getElementById("m-" + idx);
  let btn = m.getElementById("h_touch");
  btn.addEventListener("click", (ev) => {
    var day;
    if (idx < day_week)
      day = 1;
    else if (idx > (day_week + mo_days))
      day = mo_days;
    else
      day = idx - day_week + 1;
    utils.bounce("event", V, {
                              year: year,
                              month: month,
                              day: day
                            });
  });
}

function reset_date(d)
{

  month = d.getMonth();
  year = d.getFullYear();
  set_days();
}

function set_day(idx, day, today, hi)
{

  let m = document.getElementById("m-" + idx);
  let t = m.getElementById("h_text");
  t.text = (day > 0) ? (day + "") : "";
  let b = m.getElementById("h_box");
  b.style.display = (day == today) ? "inline" : "none";
  let b = m.getElementById("h_back");
  b.style.fill = hi ? "slategray" : "black";
}

// Get label for a calendar entry
//
// cd - calendar entry (0 - 36)
// ws - week start (0 - 6)
// nd - number of days in this month
//
function cal_day(cd, ws, nd)
{

  if (cd < ws)
    return 0;
  let l = cd - ws + 1;
  if (l >= nd)
    return 0;
  return l;
}

function set_days()
{
  let l, today;

  let date = new Date(year, month, 1);
  day_week = date.getDay();

  utils.label_btn("um_btn", utils.m_name(month));

  utils.label_btn("lm_btn", year + "");

  let mo_days = utils.days_per_mo(year, month) + 1;
  if (year == now.getFullYear() && month == now.getMonth())
    today = now.getDate();
  else
    today = -1;

  for (let i = 0; i < 37; i++) {
    l = cal_day(i, day_week, mo_days);
    set_day(i, l, today, utils.day_events(year, month, l));
  }

}

function new_year(off)
{

  year += off;
  set_days();
}

function new_month(off)
{

  month += off;
  if (month > 11) {
    year += 1;
    month = 0;
  } else if (month < 0) {
    year -= 1;
    month = 11;
  }
  set_days();
}
