// SPDX-License-Identifier: GPL-3.0
//
// Copyright (C) 2019, Donald Dugger
//

import document from "document";
import { logger } from "../common/utils";
import * as utils from "../common/utils";

let V;
let P;

let events;
let num_old;

export function init(_V)
{

  V = _V;
  P = V.G.P;

  utils.scr_init("Configuration", V);

  utils.image_btn("ul_btn", "icons/left_btn.png", (btn) => {
    utils.bounce("config2", V);
  });
  utils.image_btn("ur_btn", "icons/right_btn.png", (btn) => {
    utils.bounce("cfg_select", V);
  });

  //
  // AM/PM display
  //
  //  cfg_ampm - show/hide am/pm indicator
  //  cfg_am   - show am & pm indicators
  //  cfg_pm   - show pm only
  //
  //  P.ampm bit flag controlling indicators
  //    0/1 = PM only, AM/PM
  //    0/2 = show AM/PM at all
  //
  let cfg_ampm = document.getElementById("cfg_ampm");
  cfg_ampm.image = (P.ampm & 1) ? "icons/on.png" : "icons/off.png";
  cfg_ampm.addEventListener("click", (evt) => {
    P.ampm ^= 1;
    cfg_ampm.image = (P.ampm & 1) ? "icons/on.png" : "icons/off.png";
    utils.prefs_save(P);
  })
  let cfg_text = document.getElementById("cfg_am_text");
  cfg_text.text = (P.ampm & 2) ? "PM" : "AM/PM";  
  let cfg_am = document.getElementById("cfg_am");
  cfg_am.addEventListener("click", (evt) => {
    P.ampm ^= 2;
    cfg_text.text = (P.ampm & 2) ? "PM" : "AM/PM";  
    utils.prefs_save(P);
  })

  //
  // 12/24 hour display
  //
  let cfg_hr12_bck = document.getElementById("cfg_hr12_bck");
  let cfg_hr24_bck = document.getElementById("cfg_hr24_bck");
  cfg_hr12_bck.style.fill = P.hr24 ? "black" : "red";
  cfg_hr24_bck.style.fill = P.hr24 ? "red" : "black";

  let cfg_hr12 = document.getElementById("cfg_hr12");
  cfg_hr12.addEventListener("click", (evt) => {
    cfg_hr12_bck.style.fill = "red";
    cfg_hr24_bck.style.fill = "black";
    P.hr24 = 0;
    utils.prefs_save(P);
  })
  let cfg_hr24 = document.getElementById("cfg_hr24");
  cfg_hr24.addEventListener("click", (evt) => {
    cfg_hr24_bck.style.fill = "red";
    cfg_hr12_bck.style.fill = "black";
    P.hr24 = 1;
    utils.prefs_save(P);
  })

  //
  // Events
  //
  let evt_clear = document.getElementById("evt_clear");
  evt_clear.addEventListener("click", (evt) => {
    utils.clear_events(num_old > 0);
    set_events();
  });
  set_events();
//utils.ls();

  return false;
}

function set_events()
{

  let res = utils.list_events(new Date());
  num_old = res.old;

  let t = "";
  if (num_old > 0)
    t = num_old + "/";
  t += res.events.length + " months";

  document.getElementById("evt_count").text = t;
  document.getElementById("evt_old").style.display = (num_old > 0) ? "inline" : "none";
  document.getElementById("evt_reset").style.display = (res.events.length > 0) ? "inline" : "none";
}
