// SPDX-License-Identifier: GPL-3.0
//
// Copyright (C) 2019, Donald Dugger
//

import document from "document";
import * as C from "../common/constants";
import { logger } from "../common/utils";
import * as utils from "../common/utils";

let V;

let first;
let busy;
let busy_max;

let type = "Busy";
let now;
let days;
let days_index;

let page_sz = 4;

export function init(_V, _O)
{

  V = _V;

  utils.text_btn("um_btn", "None", "fb-white", "fb-blue", (btn) => {
    if (_O.days)
      utils.bounce("face_%", V);
    else
      utils.bounce("calendar_%", V, { date: new Date(now.year, now.month, now.day) });
  });
  
  adj_layout(V.G.sdk, document.getElementById("event"));

  utils.image_btn("ul_btn", "icons/left_btn.png", (btn) => {
    new_day(-1);
  });
  utils.image_btn("ur_btn", "icons/right_btn.png", (btn) => {
    new_day(1);
  });

  if (_O.days) {
    utils.text_btn("lm_btn", "Upcoming", "fb-white", "fb-blue", undefined);
  } else {
    utils.text_btn("lm_btn", "New", "fb-white", "fb-blue", (btn) => {
      utils.bounce("set_event", V, {
                                year: now.year,
                                month: now.month,
                                day: now.day,
                                index: -1,
                                start: 12*60,
                                length: 0,
                                name: "Busy"
                             });
    });
  }
  utils.image_btn("ll_btn", "icons/up.png", (btn) => {
    sh_events(-page_sz);
  });
  utils.image_btn("lr_btn", "icons/down.png", (btn) => {
    sh_events(page_sz);
  });

  days = [];
  if (_O.days) {
    get_events();
  } else {
    let mo_days = utils.days_per_mo(_O.year, _O.month);
    for (let i = 0; i < mo_days; i++)
      days[i] = {
                  year: _O.year,
                  month: _O.month,
                  day: i + 1
                };
    days_index = _O.day - 1;
  }

  new_day(0);

  return false;
}

function adj_layout(sdk, r)
{

  if (sdk === "sdk5") {
    let svg = document.getElementById("buttons");
    svg.y = 280;
  }
  // Ionic (the only device with non-square dimensions) can
  // only display 3 events at a time
  if (r.width != r.height) {
    page_sz = 3;
    utils.show_btn("ev_tm-3", false);
    utils.show_btn("ev_nm-3", false);
  }
}

function get_events()
{
  let date, mo_days;
  let yr, mo;

  let res = utils.list_events(new Date());
  days = [];
  let index = 0;
  for (let i = res.old; i < res.events.length; i++) {
    date = res.events[i];
    yr = parseInt(date.substring(2, 6));
    mo = parseInt(date.substring(7));
    let mo_days = utils.get_days(yr, mo);
    for (let idx = 1; idx < 31; idx++)
      if (mo_days[idx])
        days[index++] = {
                          year: yr,
                          month: mo,
                          day: idx
                        };
  }
  days_index = 0;
}

function duration(start, length)
{

  return utils.min2str(start, false, V.G.P) + "-" + utils.min2str(length, false);
}

function sh_events(inc)
{
  let ev, bn;

  for (let i = 0; i < page_sz; i++) {
    utils.show_btn("ev_tm-" + i, false);
    utils.show_btn("ev_nm-" + i, false);
  }
  
  first += inc;

  document.getElementById("ll_btn").style.display = (first > 0) ? "inline" : "none";
  document.getElementById("lr_btn").style.display = ((first + page_sz) < busy_max) ? "inline" : "none";

  if (busy) {
    let i;
    let max = first + page_sz;
    if (max >= busy_max)
      max = busy_max;
    for (let idx = first; idx < max; idx++) {
      ev = busy[idx];
      i = idx - first;
      utils.show_btn("ev_tm-" + i, true);
      utils.text_btn("ev_tm-" + i, duration(ev.start, ev.length), undefined, undefined, (btn) => {
                        ev = busy[idx];
                        utils.bounce("set_event", V, {
                              year: now.year,
                              month: now.month,
                              day: now.day,
                              index: idx,
                              start: ev.start,
                              length: ev.length,
                              name: ev.type
                           });
                    });
      utils.show_btn("ev_nm-" + i, true);
      utils.text_btn("ev_nm-" + i, ev.type, undefined, undefined, (btn) => {
                        ev = busy[idx];
                        utils.bounce("set_event", V, {
                              year: now.year,
                              month: now.month,
                              day: now.day,
                              index: idx,
                              start: ev.start,
                              length: ev.length,
                              name: ev.type
                           });
                    });
    }
  }
}

function get_extant()
{

  days[0] = {
              year: 2022,
              month: 11,
              day: 1
            }
  days_index = 0;
}

function new_day(inc)
{

  let ul_btn = document.getElementById("ul_btn");
  let ur_btn = document.getElementById("ur_btn");
  ul_btn.style.display = "none";
  ur_btn.style.display = "none";

  first = 0;
  days_index += inc;
  if (days_index < 0)
    days_index = 0;
  else if (days_index >= days.length)
    days_index = days.length - 1;

  if (days.length == 0)
    return;

  if (days_index > 0)
    ul_btn.style.display = "inline";
  if (days_index < (days.length - 1))
    ur_btn.style.display = "inline";

  let d = days[days_index];
  now = {
          year: d.year,
          month: d.month,
          day: d.day
        };
  utils.label_btn("um_btn", utils.m_name(now.month) + " " + now.day);

  V.G.ev_date = new Date(now.year, now.month, now.day);
  busy = utils.day_events(now.year, now.month, now.day);
  busy_max = busy ? busy.length : 0;

  sh_events(0);
}
