// SPDX-License-Identifier: GPL-3.0
//
// Copyright (C) 2019, Donald Dugger
//

import document from "document";
import { logger } from "../common/utils";
import * as utils from "../common/utils";

let V;
let O;

let tz_sign = 0;
let sign;
let cur_dig;
let digs = [];

export function init(_V, _O)
{
  var btn, txt, touch;
  var touch, dig;

  V = _V;
  O = _O;

  utils.scr_init("", V);

  utils.text_btn("tz_yes", "Ok", "fb-black", "fb-green", (btn) => {
    O.save(get_off(), O.opt);
    utils.bounce(O.caller, V, O.opt);
  });
  let y_btn = document.getElementById("tz_yes");
  let y_txt = y_btn.getElementById("b_text");
  y_txt.x = 76;

  utils.text_btn("tz_no", "Cancel", "fb-black", "fb-red", (btn) => {
    utils.bounce(O.caller, V, O.opt);
  });
  let n_btn = document.getElementById("tz_no");
  let n_txt = n_btn.getElementById("b_text");
  n_txt.x = 100;

  sign = document.getElementById("tz-sign");
  sign.text = "+";
  sign.addEventListener("click", (evt) => {
    tz_sign ^= 1;
    sign.text = (tz_sign > 0) ? "-" : "+";
  })
  for (let i = 0; i < 10; i++)
  {
    btn = document.getElementById("numb-" + i);
    txt = btn.getElementById("b_text");
    txt.text = "" + i;
    touch = btn.getElementById("b_touch");
    touch.addEventListener("click", (evt) => {
      if (ok_dig(cur_dig, i)) {
        set_numb(cur_dig++, "" + i, "black");
        if (cur_dig >= O.no_digs)
          cur_dig = 0;
        set_numb(cur_dig, null, "red");
      }
    })
  }

  let hidden = document.getElementById("dig_" + ((O.no_digs > 4) ? 4 : 6));
  hidden.style.display = "none";
  let d_scr = document.getElementById("dig_" + O.no_digs);
  d_scr.style.display = "inline";
  for (let i = 0; i < O.no_digs; i++) {
    dig = d_scr.getElementById("tz_dig" + i);
    digs[i] = dig;
    touch = dig.getElementById("b_touch");
    touch.addEventListener("click", (evt) => {
      set_numb(cur_dig, null, "black");
      cur_dig = i;
      set_numb(cur_dig, null, "red");
    })
  }

  var off = O.off;
  tz_sign = (off < 0) ? 1 : 0;
  sign.text = (tz_sign > 0) ? "-" : "+";
  if (off < 0)
    off = -off;
  let hr = parseInt(off / (60 * 60));
  off -= hr * (60 * 60);
  let min = parseInt(off / 60);
  let sec = off - (min * 60);

  cur_dig = 0;
  set_digs(hr, 0, 1);
  set_digs(min, 2, 3);
  if (O.no_digs > 4)
    set_digs(sec, 4, 5);
  set_numb(cur_dig, null, "red");

  return false;
}

function set_numb(idx, n, bg)
{

  let d = digs[idx];
  if (n) {
    let l = d.getElementById("b_text");
    l.text = n;
  }
  let b = d.getElementById("b_back");
  b.style.fill = bg;
}

function set_digs(n, d1, d2)
{
  
  let ten = parseInt(n / 10);
  set_numb(d1, "" + ten, "black");
  set_numb(d2, "" + (n - (ten * 10)), "black");
}

function ok_dig(pos, value)
{

  switch (pos) {

  case 0:
    if (value > 1)
      return false;
    return true;

  case 2:
  case 4:
    if (value > 5)
      return false;
    return true;

  }
  return true;
}

function get_dig(idx)
{

  let d = digs[idx];
  let l = d.getElementById("b_text");
  return parseInt(l.text);
}

function get_off()
{

  let hr = (get_dig(0) * 10) + get_dig(1);
  let min = (get_dig(2) * 10) + get_dig(3);
  let sec = (O.no_digs > 4) ? ((get_dig(4) * 10) + get_dig(5)) : 0;
  let off = (hr * (60 * 60)) + (min * 60) + sec;
  return (tz_sign > 0) ? -off : off;
}
