// SPDX-License-Identifier: GPL-3.0
//
// Copyright (C) 2019, Donald Dugger
//

import document from "document";
import { vibration } from "haptics";
import Constants from "../common/Constants";
import { logger } from "../common/utils";
import * as utils from "../common/utils";

let V;
let T;
let C;

let ur_btn;

//
// timer interrupts
//
var fire = 0;
var haptic = 0;

export function init(_V)
{
  var btn, txt, img, timer_value;

  V = _V;
  C = V.G.C;
  T = V.G.T;

  utils.scr_init("Timer", V);

  utils.text_btn("u_btn", "Chronograph", "fb-white", "fb-blue", (btn) => {
    utils.bounce("face_%", V);
  });

  utils.image_btn("ur_btn", "icons/right_btn.png", (btn) => {
    utils.bounce("laps", V);
  });
  ur_btn = document.getElementById("ur_btn");

  timer_value = document.getElementById("timer_value");
  timer_value.addEventListener("click", (evt) => {
    if (T.mode == C.TIMER_DOWN)
      utils.bounce("get_time", V, {
                                  caller: "timer",
                                  no_digs: 6,
                                  off: T.itime / 1000,
                                  save: save
                                });
  });

  btn = document.getElementById("timer_enable");
  let e_txt = btn.getElementById("b_text");
  utils.text_btn("timer_enable", "Disabled", "fb-yellow", "fb-red", (btn) => {
    T.enable = !T.enable;
    e_txt.text = (T.enable ? "Enabled" : "Disabled");
  });
  e_txt.text = (T.enable ? "Enabled" : "Disabled");

  utils.text_btn("timer_clear", "Reset", "fb-yellow", "fb-red", (btn) => {
    T.stime = Date.now();
    T.etime = T.stime;
    utils.laps_reset(T);
    let ticks = (T.mode == C.TIMER_UP) ? 0 : T.itime;
    timer_value.text = utils.milli2str(ticks, true);
  });
  
  btn = document.getElementById("timer_mode");
  let m_txt = btn.getElementById("b_text");
  utils.text_btn("timer_mode", "Up", "fb-yellow", "fb-red", (btn) => {
    T.mode = (T.mode == C.TIMER_UP) ? C.TIMER_DOWN : C.TIMER_UP;
    set_mode(T.mode, m_txt, ur_btn, true);
    timer_value.text = utils.milli2str(utils.elapsed(Date.now(), T), true);
    utils.laps_reset(T);
  });
  set_mode(T.mode, m_txt, ur_btn, false);

  timer_value.text = utils.milli2str(utils.elapsed(Date.now(), T), true);

  return false;
}

function set_mode(mode, txt, btn, reset)
{

  if (mode == C.TIMER_UP) {
    txt.text = "Up";
    btn.style.display = "inline";
  } else {
    txt.text = "Down";
    btn.style.display = "none";
  }
  if (reset)
    T.etime = (mode == C.TIMER_UP) ? T.stime : (T.stime + T.itime);
}
function save(offset)
{

  T.itime = offset * 1000;
  T.etime = T.stime;
}
