
/**
 * A basic module to simplify navigation within multi-view applications.
 *
 * Following code copied from Vlad Balin's github project:
 *    https://github.com/gaperton/sdk-multi-view
 * (no license appearant in the code so it should be OK to use it)
 */
import document from "document";
import { memory } from "system";
import * as prefs from "../common/prefs";

/**
 * @param {string} _prefix The folder name where the view files reside.
 * Initialize the views module with views from a specific folder.
 * @param {Object} _views An map of view names to an associated JavaScript `import()`.
 */

let _views;
let _clean_up;
let _sdk = "unknown";

const viewport = {
  init( views ) {
    _views = views;
    if (document.getElementById("sense"))
      _sdk = "sdk5";
    else
      _sdk = "sdk4";
    return _sdk;
  },

  // Global context shared across all views.
  G : {},
 
  /**
   * Navigate to a specific view using its view name.
   * @param {string} viewName The name of a .gui file, excluding its path or file extension.
   * @param {object} options Object with options to be passed to view's init() function.
   */
  replace( viewName, options ){
    if (_clean_up)
      _clean_up();

    let len = viewName.length;
    if (viewName.substr(len - 1, len) === "%")
      viewName = viewName.substr(0, len - 1) + _sdk;
    if (_sdk === "sdk4") {
      _views[ viewName ]()
        .then(({ init }) => {
          document.replaceSync(`./resources/${viewName}.view`);
          _clean_up = init( viewport, options );
//console.log("replaced:" + viewName + " - " + memory.js.used + "/" + memory.js.total);
        })
        .catch( e => {
          console.error( e );
          console.error(`Failed to load view JS: ${viewName}`);
        });
    } else {
      _views[ viewName ]()
        .then(({ init }) => {
          document.location.replace(`./resources/${viewName}.view`).then(() => {
            _clean_up = init( viewport, options, );
//console.log("replaced:" + viewName + " - " + memory.js.used + "/" + memory.js.total);
          });
        })
        .catch( e => {
          console.error( e );
          console.error(`Failed to load view JS: ${viewName}`);
        });
    }
  }
}

export default viewport;
